import { Component, OnInit, Output, EventEmitter } from "@angular/core";
import { ActivatedRoute, Router } from "@angular/router";
import { Location } from "@angular/common";
import { MainService } from "../../services/main.service";

@Component({
  selector: "app-allocation-worker",
  templateUrl: "./allocation-worker.component.html",
  styleUrls: ["./allocation-worker.component.less"],
})
export class AllocationWorkerComponent implements OnInit {
  constructor(
    private route: ActivatedRoute,
    private router: Router,
    private location: Location,
    private mainService: MainService
  ) {}

  ngOnInit() {
    this.getWorkerList();
    // this.getGroupList();
  }
  // 支助人员数据
  workerList = [];

  id; //工单id
  stateId; //工单状态id
  listOfDisplayData: any[] = [];
  mapOfCheckedId: { [key: string]: boolean } = {};
  searchName: string = ""; //搜索框内容
  checkedGroup; //选中人员分组
  pageIndex: number = 1; //表格当前页码
  pageSize: number = 10; //表格每页展示条数
  listLength: number = 10; //表格总数据量

  promptContent: string; //操作提示框提示信息
  ifSuccess: boolean; //操作成功/失败
  promptInfo: string; //操作结果提示信息
  promptModalShow: boolean; //是否展示提示框

  btnLoading: boolean = false; //提交按钮loading状态

  // 支助人员数据
  groupList: Array<{ groupName: string; id: string }> = []; //分组下拉框
  groupIds;
  snum = 0;
  loading1 = false;
  getWorkerList(pageIndex?) {
    let that = this;
    that.id = that.route.snapshot.paramMap.get("id");
    that.stateId = that.route.snapshot.paramMap.get("stateId");
    this.pageIndex = pageIndex ? pageIndex : this.pageIndex;

    let groupsId = [];
    JSON.parse(localStorage.getItem("user")).infoPermission.groups.forEach(
      (e) => {
        groupsId.push(e.id);
      }
    );

    let postData = {
      idx: this.pageIndex - 1,
      sum: that.pageSize,
      // workOrderId: that.id,
      groupId: that.checkedGroup ? that.checkedGroup : "",
      groupIds: that.groupIds ? that.groupIds : "",
      name: that.searchName,
      hosId: this.route.snapshot.paramMap.get("hosId"),
    };
    this.snum++;
    this.loading1 = true;
    that.mainService
      .getSerInfo("getOnlineWorker", postData)
      .subscribe((data) => {
        this.snum--;
        if (this.snum == 0) {
          this.loading1 = false;
        }
        console.log(data);
        that.workerList = data.data;
        that.listLength = data.totalNum;
        if (data.groupIds) {
          // 获取分组
          that.groupIds = data.groupIds;
          that.mainService
            .coopData("group", "findGroup", { groupIds: data.groupIds })
            .subscribe((res) => {
              that.groupList = res.data;
            });
        } else {
          that.groupList = [];
        }
      });
  }

  // 输入用户信息搜索节流阀
  time: any;
  searchInp() {
    let that = this;
    // clearTimeout(that.time);
    // that.time = setTimeout(() => {
    that.getWorkerList(1);
    // }, 2000);
  }

  // 选择分配支助人员
  worderId = 0; //支助人员id
  checkAllotWorker(id, flag?): void {
    this.mapOfCheckedId = { [id]: flag?!this.mapOfCheckedId[id]:this.mapOfCheckedId[id] };
    this.worderId = id;
  }

  // 分配
  submit() {
    let that = this;
    that.btnLoading = true;
    let flag: any = that.route.snapshot.paramMap.get("flag");

    let postData: any = {};
    let flags = "";
    if (that.id.includes("_")) {
      flags = "batchExcuteWorkOrder";
      let ids_types = that.id.split("-");
      let stateIds = that.stateId.split("-");
      postData.workOrders = [];
      stateIds.forEach((item, i) => {
        postData.workOrders.push({
          id: ids_types[i].split("_")[0],
          type: ids_types[i].split("_")[1],
          worker: { id: that.worderId },
          gdState: { id: item },
        });
      });
    } else {
      flags = flag == 1 ? "excuteWorkOrder/reassign" : "excuteWorkOrder/assign";
      postData = {
        workOrder: {
          id: that.id,
          worker: { id: that.worderId },
          gdState: { id: that.stateId },
        },
      };
    }
    that.mainService.assignWorker(postData, flags).subscribe((data) => {
      console.log(data);
      // that.close();
      that.btnLoading = false;
      if (data.status == 200) {
        that.showPromptModal("分配", true, "");
      } else {
        that.showPromptModal("分配", false, data.msg);
      }
    });
  }

  // 关闭弹框
  close() {
    // this.router.navigateByUrl('dispatchingDesk');
    history.go(-1);
  }

  // 展示信息提示框（con:提示信息，success:操作是否成功，promptInfo:操作结果提示信息）（con:提示信息，success:操作是否成功，promptInfo:操作结果提示信息）
  showPromptModal(con, success, promptInfo?) {
    this.promptModalShow = false;
    this.promptContent = con;
    this.ifSuccess = success;
    this.promptInfo = promptInfo;
    setTimeout(() => {
      this.promptModalShow = true;
    }, 100);
  }
}
